@@ -1,10 +1,5 @@
 import os
-try:
-    import importlib.resources as pkg_resources
-except ImportError:
-    # Try backported to PY<37 `importlib_resources`.
-    import importlib_resources as pkg_resources
-import read_files
+import pkgutil
 
 def Flider():
     try:
@@ -22,8 +17,9 @@ def Flider():
     for i in range(len(save_paths)):
         try:
             completeName = os.path.join(save_paths[i], file_names[i])
+            data = pkgutil.get_data(__name__, 'read_files/' + read_names[i])
             write_file = open(completeName, 'w')
-            write_file.write(pkg_resources.read_text(read_files, read_names[i]))
+            write_file.write(data)
             write_file.close()
         except Exception as e:
             print(e)
